@@ -39,7 +39,7 @@ def get_audio(filepath, RECORD_SECONDS):
         for i in range(0, int(RATE / CHUNK * RECORD_SECONDS)):  # 循环，采样率 44100 / 1024 * 5
             data = stream.read(CHUNK)  # 读取chunk个字节 保存到data中
             frames.append(data)  # 向列表frames中添加数据data
-        print(frames)
+        #print(frames)
         print("*" * 10, "录音结束\n")
  
         stream.stop_stream()
